# FatFS wrapper for Python

This library provides a Python wrapper around [ChaN's FatFS](http://elm-chan.org/fsw/ff/00index_e.html) library.

Note: This package is in alpha stage. Not all features are implemented, nor is it very well tested. Use at your own risk.
